import os
import queue
import logging
import requests
import threading
from time import sleep

logging.basicConfig(level=logging.DEBUG, format='(%(threadName)-9s) %(message)s')

class Asyncgram:
    def __init__(self, tg_token: str, tg_group: str, poll_interval: float = 0.1, daemon: bool = True):
        self.TG_TOKEN = tg_token
        self.TG_GROUP = tg_group
        self.TG_URL = f"https://api.telegram.org/bot{self.TG_TOKEN}/sendMessage"
        self.POLL_INTERVAL = poll_interval
        self.daemon = daemon
        self.queue = queue.Queue()
        self.__prepare_thread()

    def __prepare_thread(self):
        self.session = requests.Session()
        self.running = True
        self.stopped = False
        self.thread = threading.Thread(target=self.__alerter, daemon=self.daemon)

    def __alerter(self):
        while self.running or not self.queue.empty():
            if not self.queue.empty():
                try:
                    data = self.queue.get()
                except Exception as e:
                    logging.error("Error while trying to get item from producer queue")
                try:
                    self.session.post(self.TG_URL, data)
                except:
                    logging.error("Error while trying to send message to telegram")
            sleep(self.POLL_INTERVAL)
        self.stopped = True

    def put(self, item: str, group: str = None):
        if group is None:
            self.queue.put({'chat_id': str(self.TG_GROUP), "text": item})
        else:
            self.queue.put({'chat_id': str(group), "text": item})

    def start(self):
        self.thread.start()

    def stop(self):
        self.running = False
        while not self.stopped: sleep(0.1) 
        self.thread.join()


# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['asyncgram']

package_data = \
{'': ['*']}

install_requires = \
['requests']

setup_kwargs = {
    'name': 'asyncgram',
    'version': '0.0.4',
    'description': 'A lightweight, asynchronous telegram logging client',
    'long_description': '# Telegram requirements\n\nTo be able to use this tool, you will require a Telegram bot token and a group chat ID. \n\n[Telegram bot token reference](https://core.telegram.org/bots#6-botfather)\n\n[Telegram group chat ID reference](https://stackoverflow.com/questions/32423837/telegram-bot-how-to-get-a-group-chat-id)\n\n# Installation\n\n```\npip install asyncgram\n```\n\n# Usage\n\nOnce you have your telegram bot token and group chat ID, and you\'ve install asyncgram, you are ready to get started. \n\n## Creating a client\n\n```\nfrom asyncgram import Asyncgram\n\n# replace XXX with your keys\nTG_BOT_TOKEN = "XXX"\nTG_GROUP_ID = "XXX"\n\nclient = Asyncgram(\n    tg_token = TG_BOT_TOKEN, \n    tg_group = TG_GROUP_ID\n)\n```\n\n## Logging messages\n\n```\nclient.start()\n\nmessages = [\n    \'Hello world\',\n    \'My name is codeman\',\n    \'My birthday was yesterday.\'\n]\n\nfor msg in messages: client.put(msg)\n\nclient.stop()\n```\n\nThis is a toy example to get you started. Recommended usage would be to put relevant messages from some form of a websocket connection such that it\'s logged in an asynchronous way.\n\n# Donations\n\nIf you liked this tool and would like to support me, kindly send your donations in ETH to 0xB08f9B316ddBCA4Dc5736153Cd63B8d9Bec46Bab',
    'author': 'sumermalhotra',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3,<4',
}


setup(**setup_kwargs)
